/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/*                                                                            */
/* Compras e Suprimentos                                                      */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Nome: 8490_SUPSTP_MELHOR_PRECO_AUTO                                        */
/*                                                                            */
/* Descrio:                                                                 */
/*   Carrega os melhores preos para os produtos de uma cotao de um         */
/*   um fornecedor do tipo alternativo                                        */
/*                                                                            */
/* Criao:                                                                   */
/*    05/07/2000 - Adriano de Araujo                                          */
/*                                                                            */
/* Manutenes:                                                               */
/*   /  /   -                                                                 */
/*                                                                            */
/******************************************************************************/

IF EXISTS (SELECT * FROM sysobjects O, sysusers U
          WHERE
            o.name = 'MELHOR_PRECO_AUTO'  and
            type = 'P'                  and
            u.uid = o.uid               and
            u.name = USER)

   DROP PROCEDURE MELHOR_PRECO_AUTO;
GO

CREATE PROCEDURE MELHOR_PRECO_AUTO
                  @P_CDFILIAL VARCHAR(4),
                  @P_NRCOLEPRECO VARCHAR(10),
                  @P_DTINI DATETIME,
                  @P_DTFIN DATETIME
AS
DECLARE @V_CDOPERADOR VARCHAR(12);

BEGIN
  SELECT
    @V_CDOPERADOR = CDOPERADOR
  FROM
    COLETAPR
  WHERE
    CDFILIAL    = @P_CDFILIAL    AND
    NRCOLEPRECO = @P_NRCOLEPRECO

  UPDATE ITEMCOLE
  SET
  ITEMCOLE.IDITMCOTPREC = 'S',
  ITEMCOLE.VRPRECUNIITM = MIN_PR.VRPRECUNIITM
  FROM
    FORNECEDOR,
   (SELECT
     ITEMCOLE.CDPRODUTO,
     ITEMCOLE.CDREGIAO,
     MIN(ITEMCOLE.VRPRECUNIITM) AS VRPRECUNIITM
   FROM
     ITEMCOLE,
     FORNECEDOR
   WHERE
     ITEMCOLE.CDFILIAL    = @P_CDFILIAL AND
     ITEMCOLE.DTINIVALITM >= @P_DTINI   AND
     ITEMCOLE.DTFINVALITM <= @P_DTFIN    AND
     ITEMCOLE.CDFORNECED  = FORNECEDOR.CDFORNECED AND
     FORNECEDOR.IDTIPOFORN = 'N'
   GROUP BY
     ITEMCOLE.CDPRODUTO,
     ITEMCOLE.CDREGIAO) MIN_PR
  WHERE
    ITEMCOLE.CDFILIAL    = @P_CDFILIAL    AND
    ITEMCOLE.NRCOLEPRECO = @P_NRCOLEPRECO AND

    ITEMCOLE.CDPRODUTO  = MIN_PR.CDPRODUTO AND
    ITEMCOLE.CDREGIAO   = MIN_PR.CDREGIAO  AND

    ITEMCOLE.CDFORNECED  = FORNECEDOR.CDFORNECED AND
    FORNECEDOR.IDTIPOFORN = 'A' AND
    EXISTS
     (SELECT
        CDPRODUTO
      FROM
        PRODCOMP
      WHERE
        PRODCOMP.CDOPERADOR = @V_CDOPERADOR  AND
        ITEMCOLE.CDPRODUTO LIKE PRODCOMP.CDPRODUTO + '%'); 

  IF @@ROWCOUNT > 0
  BEGIN
    UPDATE COLETAPR
    SET IDTIPCOLREG = 'G'
    WHERE
      CDFILIAL    = @P_CDFILIAL AND
      NRCOLEPRECO = @P_NRCOLEPRECO;
  END;
END;

GO
